@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: ZephyrusSettings.py 11662 2019-07-22 00:54:08Z Trista $
+# $Id: ZephyrusSettings.py 11936 2020-02-19 07:31:27Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Trista $ (last)
-# $Date: 2019-07-22 08:54:08 +0800 (週一, 22 七月 2019) $
-# $Revision: 11662 $
+# $Author: Lavender $ (last)
+# $Date: 2020-02-19 16:31:27 +0900 (週三, 19 二月 2020) $
+# $Revision: 11936 $
 """
 Default settings for this project if it can't import settings.
 """
@@ -185,7 +185,7 @@ INSTALLED_APPS = (
     'Iuppiter.test',
     'Zephyrus.tests',
     'Zephyrus.boilerplate',  
-    
+    'Zephyrus.facebook',
 )
 
 SITE_ID = 1
