@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 11821 2019-12-26 02:47:12Z Lavender $
+# $Id: setup.py 11914 2020-02-09 13:48:38Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-12-26 10:47:12 +0800 (週四, 26 十二月 2019) $
-# $Revision: 11821 $
+# $Date: 2020-02-09 22:48:38 +0900 (週日, 09 二月 2020) $
+# $Revision: 11914 $
 
 import os
 import sys
@@ -630,13 +630,13 @@ if __name__ == "__main__":
         if django.VERSION <= (2, 0): 
             try:
                 os.system(
-                    "pip install -U djangocms_text_ckeditor==3.5.3 --no-deps")
+                    "pip install -U djangocms_text_ckeditor==3.8.0 --no-deps")
                 os.system(
-                    "pip install -U html5lib==0.9999999 --no-deps")
+                    "pip install -U html5lib==1.0.1 --no-deps")
                 os.system("pip install cmsplugin-filer==1.1.3")
             except Exception as e:
                 logger.error(
-                    colored("Can't install djangocms_text_ckeditor==3.5.3", 
+                    colored("Can't install djangocms_text_ckeditor==3.8.0", 
                             "red"))
                 sys.exit(1)
         else:
