@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 11925 2020-02-12 14:02:54Z Lavender $
+# $Id: cms_plugins.py 11936 2020-02-19 07:31:27Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-02-12 23:02:54 +0900 (週三, 12 二月 2020) $
-# $Revision: 11925 $
+# $Date: 2020-02-19 16:31:27 +0900 (週三, 19 二月 2020) $
+# $Revision: 11936 $
 
 import requests
 import json
@@ -74,6 +74,53 @@ def getFanPageId(accessToken, url):
         return fanPageId
     else:
         return None
+        
+        
+def getFanPage(url, limit):
+    # get data
+    req = requests.get("%sposts/?ref=page_internal&_fb_noscript=1" % url)  
+    content = req.text
+    soup = BeautifulSoup(content, 'html.parser')
+    
+    # create object
+    fpList = []
+    for i, div in enumerate(soup.find_all('div', class_="_4-u2 _4-u8"), 1):
+        pageId = i
+        
+        # createdTime
+        createdTime = div.find_all('span', class_="timestampContent")[0].text
+        
+        # message
+        msg = div.find_all('div', class_='text_exposed_root')
+        if msg:
+            msg = mark_safe(str(div.find_all('div', class_='text_exposed_root')[0]))
+        else:
+            msg = ''
+        
+        # image
+        images = div.find_all('img', class_="scaledImageFitWidth img")
+        if images:
+            mainImg = div.find_all('img', class_="scaledImageFitWidth img")[0].get("data-src", "#")
+        else:
+            mainImg = None
+           
+        # type
+        postType = "abc"
+        
+        # link
+        links = div.find_all('a', class_="_5pcq")
+        if links:
+            link = "https://www.facebook.com%s" % div.find_all('a', class_="_5pcq")[0].get("href", "#")
+        else:
+            continue
+            
+        subattachments = []
+        fp = FanPage(pageId, createdTime, msg, mainImg, postType, link, subattachments)
+        fpList.append(fp)
+        if len(fpList) == limit:
+            break
+   
+    return fpList
 
 class FacebookFanPlugin(CMSPluginBase):
     model = FacebookFan
@@ -87,12 +134,12 @@ class FacebookFanPlugin(CMSPluginBase):
                 'description': _('<h2>Main:</h2>'),
                 'fields': ('url', 'limit',),
             }),
-            (None, {
-                'description': _('<h2>Choose article display mode:</h2>'),
-                'fields': ('unknownDisplay', 'videoDisplay', 'albumDisplay', 
-                           'shareDisplay', 'commerceDisplay', 
-                           'onlyMessageDisplay',),
-            }),
+            # (None, {
+                # 'description': _('<h2>Choose article display mode:</h2>'),
+                # 'fields': ('unknownDisplay', 'videoDisplay', 'albumDisplay', 
+                           # 'shareDisplay', 'commerceDisplay', 
+                           # 'onlyMessageDisplay',),
+            # }),
             (None, {
                 'description': _('<h2>Other:</h2>'),
                 'fields': ('renderTemplate',),
@@ -107,48 +154,7 @@ class FacebookFanPlugin(CMSPluginBase):
         ])
 
     def render(self, context, instance, placeholder):
-        # get data
-        req = requests.get("%sposts/?ref=page_internal&_fb_noscript=1" % instance.url)  
-        content = req.text
-        soup = BeautifulSoup(content, 'html.parser')
-        
-       
-        fpList = []
-        for i, div in enumerate(soup.find_all('div', class_="_4-u2 _4-u8"), 1):
-            pageId = i
-            
-            # createdTime
-            createdTime = div.find_all('span', class_="timestampContent")[0].text
-            
-            # message
-            msg = div.find_all('div', class_='text_exposed_root')
-            if msg:
-                msg = mark_safe(str(div.find_all('div', class_='text_exposed_root')[0]))
-            else:
-                msg = ''
-            
-            # image
-            images = div.find_all('img', class_="scaledImageFitWidth img")
-            if images:
-                mainImg = div.find_all('img', class_="scaledImageFitWidth img")[0].get("data-src", "#")
-            else:
-                mainImg = None
-               
-            # type
-            postType = "abc"
-            
-            # link
-            links = div.find_all('a', class_="_5pcq")
-            if links:
-                link = "https://www.facebook.com%s" % div.find_all('a', class_="_5pcq")[0].get("href", "#")
-            else:
-                continue
-                
-            subattachments = []
-            fp = FanPage(pageId, createdTime, msg, mainImg, postType, link, subattachments)
-            fpList.append(fp)
-            if len(fpList) == instance.limit:
-                break
+        fpList = getFanPage(instance.url, instance.limit)
        
         context.update({
             'fpList': fpList,
@@ -263,6 +269,38 @@ class FacebookFanPlugin(CMSPluginBase):
         
         return context
         
+def getFanPhoto(url, limit):
+    # get data
+    req = requests.get(url)  
+    content = req.text
+    startStr = '''"media":{"edges":['''
+    endStr = '''],"page_info":'''
+    content = "[%s]" % content[content.find(startStr) + len(startStr):content.find(endStr)]
+    data = json.loads(content)
+    
+    # create objects
+    photoList = []
+    for d in data:
+        node = d.get("node")
+        if not node:
+            continue
+            
+        name = None
+        url = None
+        link = None
+        if not 'image' in node:
+            continue
+       
+        url = node.get("image", {}).get("uri", '#')
+        #name = mark_safe(node.get("album", {}).get("name", '').replace('\n', '<br />'))
+        link = node.get("url", '#')
+        
+        photoList.append(Photo(name, url, link))
+        if len(photoList) == limit:
+            break
+            
+    return photoList
+        
 class FacebookPhotoPlugin(CMSPluginBase):
     model = FacebookPhoto
     module = _("Zephyrus Facebook")
@@ -276,35 +314,7 @@ class FacebookPhotoPlugin(CMSPluginBase):
         ])
 
     def render(self, context, instance, placeholder):
-        # get data
-        req = requests.get(instance.url)  
-        content = req.text
-        startStr = '''"media":{"edges":['''
-        endStr = '''],"page_info":'''
-        content = "[%s]" % content[content.find(startStr) + len(startStr):content.find(endStr)]
-        data = json.loads(content)
-        
-        # create objects
-        photoList = []
-        for d in data:
-            node = d.get("node")
-            if not node:
-                continue
-                
-            name = None
-            url = None
-            link = None
-            if not 'image' in node:
-                continue
-           
-            url = node.get("image", {}).get("uri", '#')
-            #name = mark_safe(node.get("album", {}).get("name", '').replace('\n', '<br />'))
-            link = node.get("url", '#')
-            
-            photoList.append(Photo(name, url, link))
-            if len(photoList) == instance.limit:
-                break
-        
+        photoList = getFanPhoto(instance.url, instance.limit)
         context.update({
             'photoList': photoList,
         })
