@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11791 2019-12-10 12:41:41Z Lavender $
+# $Id: views.py 11929 2020-02-17 04:57:08Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,18 +11,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2019-12-10 20:41:41 +0800 (週二, 10 十二月 2019) $
-# $Revision: 11791 $
+# $Author: Trista $
+# $Date: 2020-02-17 13:57:08 +0900 (週一, 17 二月 2020) $
+# $Revision: 11929 $
 
 import datetime
 import logging
 import urllib
 import six
+import hashlib
 
 from unidecode import unidecode
 
-from django.shortcuts import redirect, get_object_or_404
+from django.shortcuts import redirect, get_object_or_404, render
 from django.views.generic import View
 from django.core.mail import send_mail
 from django.conf import settings
@@ -33,6 +34,8 @@ from django.contrib import auth
 from django.core.validators import validate_email
 from django.core.exceptions import ValidationError
 from django.template.defaultfilters import slugify
+from django.urls import reverse
+from django.conf import settings
 
 from djangocms_forms.models import FormDefinition
 from djangocms_forms.utils import hashid_to_int
@@ -41,6 +44,9 @@ from djangocms_forms.forms import FormBuilder
 from Zephyrus.landing import ErrorCode
 from Zephyrus.landing.models import Email
 
+from Zephyrus.blog_extension.models import ActionRecord, Action
+from filer.models.filemodels import File
+
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 logger.addHandler(logging.StreamHandler())
@@ -66,6 +72,31 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, formId=None):
             key = slugify(unidecode(field.label).replace('-', '_'))
             value = form.cleaned_data.get(key, '(no input)')
             dataDict[key] = {'value': value, 'field': field,}
+
+        if 'fileId' in request.POST:
+            fileId = request.POST.get('fileId')
+            targetFile = get_object_or_404(File, pk=fileId)
+            action = get_object_or_404(
+                Action,
+                file=targetFile,
+                formdefinition_ptr_id=landingForm.id
+            )
+            m = hashlib.md5()
+            data = f"{email}{targetFile.original_filename}"
+            m.update(data.encode("utf-8"))
+            token = m.hexdigest()
+            actionRecord, created = ActionRecord.objects.get_or_create(
+                action=action,
+                email=email,
+                url=fromUrl,
+                defaults={'token':token, 'count':0}
+            )
+            if not created:
+                actionRecord.count = actionRecord.count + 1
+            actionRecord.save()
+            link = reverse('showActionFile') + '?key=' + targetFile.sha1
+            fileData = {'link': link, 'token': token}
+
     elif formId:
         formId = hashid_to_int(formId)
         landingForm = get_object_or_404(FormDefinition, pk=formId)
@@ -157,11 +188,17 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, formId=None):
                     fail_silently=False
                 )
             else:
-                mail = Template(landingForm.post_submit_msg)
+                if fileId:
+                    replaceStr.update(fileData)
+                    mail = get_template('landing/FileVerification.txt')
+                    message = mail.render(replaceStr)
+                else:
+                    mail = Template(landingForm.post_submit_msg)
+                    message = mail.render(Context(replaceStr))
                 title = landingForm.email_subject
                 send_mail(
                     title,
-                    mail.render(Context(replaceStr)),
+                    message,
                     settings.DEFAULT_FROM_EMAIL,
                     [email.email,],
                     fail_silently=False
@@ -213,3 +250,14 @@ class LandingSocialView(View):
         auth.logout(request)
         return sendAndRedirect(
             request, email, fromUrl, redirectTo, formId=formId)
+
+
+
+def showActionFile(request):
+    key = request.GET.get('key')
+    if request.GET.get('token'):
+        actionRecord = get_object_or_404(ActionRecord, action__file__sha1=key, token=request.GET.get('token'))
+        return redirect(settings.MEDIA_URL + str(actionRecord.action.file.file))
+
+    else:
+        return render(request, 'landing/FileVerification.html', {'key': key})
