@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: BuildBoilerplateTest.py 11376 2019-03-03 14:21:00Z Lavender $
+# $Id: BuildBoilerplateTest.py 11672 2019-08-07 18:52:04Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-03-03 22:21:00 +0800 (週日, 03 三月 2019) $
-# $Revision: 11376 $
+# $Date: 2019-08-08 03:52:04 +0900 (週四, 08 八月 2019) $
+# $Revision: 11672 $
 
 import os
 import sys
@@ -112,6 +112,25 @@ class BuildBoilerplateTest(unittest.TestCase):
                 shutil.copytree(dirPath, dst)
             else:
                 shutil.copyfile(dirPath, dst)
+                
+    def getTestTemplate(self, path):
+        path = os.path.join(HTML_DIR_PATH, path)
+        for dirName in os.listdir(path):
+            dirPath = os.path.join(path, dirName)
+            dst = os.path.join(TEMPLATES_DIR_PATH, dirName)
+            if os.path.isdir(dirPath):
+                shutil.copytree(dirPath, dst)
+            else:
+                shutil.copyfile(dirPath, dst)
+                
+    def compareTemplate(self, temp1, temp2):
+        with open(temp1, 'r') as f:
+            html1 = f.read().replace('\r\n', '\n')
+        with open(temp2, 'r') as f:
+            html2 = f.read().replace('\r\n', '\n')
+            
+        self.assertEqual(html1, html2)
+        
 
     def clearStaticDir(self):
         try:
@@ -121,6 +140,7 @@ class BuildBoilerplateTest(unittest.TestCase):
         else:
             os.mkdir(STATIC_DIT_PATH)
 
+    
     def testComment(self):
         self.runBuildBoilerplate('Comment.html', 'CommentAnswer.html', ver=2)
 
@@ -166,6 +186,33 @@ class BuildBoilerplateTest(unittest.TestCase):
         c.close()
         conn.close()
         self.assertEqual(placeholderCount, pluginCount)
+    
+    def testNested(self):
+        self.reset() 
+        self.getTestStatic('Template1')
+        self.getTestTemplate('Template1')
+        
+        os.system(
+            "%s Manage.py build_boilerplate2 %s" % (sys.executable, 
+                                                    TEMPLATES_DIR_PATH))
+                                                    
+        # index.html
+        templatePath = os.path.join(
+            TEMPLATES_DIR_PATH, 'index.html')
+        answerPath = os.path.join(
+            HTML_DIR_PATH, 'Template1Answer', 'index.html')
+            
+        self.compareTemplate(templatePath, answerPath)
+        
+        # blog/blog.html
+        templatePath = os.path.join(
+            TEMPLATES_DIR_PATH, 'blog', 'blog.html')
+        answerPath = os.path.join(
+            HTML_DIR_PATH, 'Template1Answer', 'blog', 'blog.html')
+            
+        self.compareTemplate(templatePath, answerPath)
+        
+        
         
     
     # Z只是要讓這個函數最後跑
@@ -202,7 +249,7 @@ class BuildBoilerplateTest(unittest.TestCase):
         else:
             self.assertEqual(pluginCount, 2)
         self.reset()
-    
+     
     
 if __name__ == '__main__':
     unittest.main()
